Module auth

Module auth 

Structs

GmailAuth

Enums

AuthError

Constants

BUNDLED_CLIENT_ID
Bundled OAuth client credentials for mxr. Users can override these with their own in config.toml (BYOC). Set GMAIL_CLIENT_ID and GMAIL_CLIENT_SECRET env vars at build time, or users provide their own via config.
BUNDLED_CLIENT_SECRET